@@ -7,16 +7,20 @@ if [ ! -e /etc/multivnc/multivnc_server.conf ] ; then
   chmod 666 /etc/multivnc/multivnc_server.conf
 fi
 
-cp -f src_server/po/multivnc_server.gmo \
+cp -f src_server/po/ja.mo \
       /usr/share/locale/ja/LC_MESSAGES/multivnc_server.mo
-cp -f src_server/po/zh_CN.gmo \
-      /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_server.mo
-cp -f src_server/po/vi.gmo \
-      /usr/share/locale/vi/LC_MESSAGES/multivnc_server.mo
-cp -f src_client/po/multivnc_client.gmo \
+cp -f src_client/po/ja.mo \
       /usr/share/locale/ja/LC_MESSAGES/multivnc_client.mo
-cp -f src_client/po/zh_CN.gmo \
+cp -f src_server/po/zh_CN.mo \
+      /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_server.mo
+cp -f src_client/po/zh_CN.mo \
       /usr/share/locale/zh_CN/LC_MESSAGES/multivnc_client.mo
-cp -f src_client/po/vi.gmo \
+cp -f src_server/po/vi.mo \
+      /usr/share/locale/vi/LC_MESSAGES/multivnc_server.mo
+cp -f src_client/po/vi.mo \
       /usr/share/locale/vi/LC_MESSAGES/multivnc_client.mo
+cp -f src_server/po/ro.mo \
+      /usr/share/locale/ro/LC_MESSAGES/multivnc_server.mo
+cp -f src_client/po/ro.mo \
+      /usr/share/locale/ro/LC_MESSAGES/multivnc_client.mo
 echo "MultiVNC Install COMPLETE!"
