@@ -1,19 +1,21 @@
 /*****************************************************************************/
 /*** multivnc_client.c                                                       ***/
 /*****************************************************************************/
-#include <stdio.h>
-#include <string.h>
+
+#include "vncviewer.h"
+
 #include <sys/socket.h>
 #include <resolv.h>
 #include <errno.h>
 #include <time.h>
 #include <getopt.h>
-
-#include "vncviewer.h"
+#include <sys/types.h>
+#include <signal.h>
 #include <jpeglib.h>
 #include <zlib.h>
 #include <fcntl.h>
 
+
 Bool JoinCTL ();
 void JoinVNC ();
 int CreateMultiSockToRecv (char *, short);
@@ -36,8 +38,12 @@ Display* dpy;
 char answer;
 int lock_time = 0;
 gint lock_tag;
+//gint record_tag;
 int auto_flag = 0;
 int notice_flag = 1;
+char connect_server[IDLENGTH] = "\0";
+int server_flag = 0;	// init:0, -s opt set:1, sever ID match:2
+int passwd_flag = 0;    // default(init): 0, -p opt set:1
 GtkWidget *drawing_window;
 GtkWidget *dialog_IDinput;
 GtkWidget *dialog_wait;
@@ -45,17 +51,20 @@ GtkWidget *dialog_recvAdv;
 GtkWidget *dialog_inputmiss;
 GtkWidget *lock_window;
 GtkWidget *mini_window;
-extern GtkWidget *client_drawingarea;
-extern GtkWidget *screen_label;
-extern GtkWidget *recvAdv_label;
 
 /****/
 #define BGR233_SIZE 256
 #define BUF_SIZE 5000000
 static char buf[BUF_SIZE];
 static char *bufoutptr = buf;
-static int buffered = 0;
+//static int buffered = 0;
 
+static int changePixelFormat8To16(char *src_buf, int src_size, char *new_buf);
+static int changePixelFormat8To32(char *src_buf, int src_size, char *new_buf);
+static int changePixelFormat16To8(char *src_buf, int src_size, char *new_buf);
+static int changePixelFormat16To32(char *src_buf, int src_size, char *new_buf);
+static int changePixelFormat32To8(char *src_buf, int src_size, char *new_buf);
+static int changePixelFormat32To16(char *src_buf, int src_size, char *new_buf);
 
 /* from rfbproto.c */
 static Bool HandleRRE8(int rx, int ry, int rw, int rh);
@@ -64,9 +73,15 @@ static Bool HandleRRE32(int rx, int ry, int rw, int rh);
 static Bool HandleCoRRE8(int rx, int ry, int rw, int rh);
 static Bool HandleCoRRE16(int rx, int ry, int rw, int rh);
 static Bool HandleCoRRE32(int rx, int ry, int rw, int rh);
-static Bool HandleHextile8(int rx, int ry, int rw, int rh);
-static Bool HandleHextile16(int rx, int ry, int rw, int rh);
-static Bool HandleHextile32(int rx, int ry, int rw, int rh);
+static Bool HandleHextile8To8(int rx, int ry, int rw, int rh);
+static Bool HandleHextile8To16(int rx, int ry, int rw, int rh);
+static Bool HandleHextile8To32(int rx, int ry, int rw, int rh);
+static Bool HandleHextile16To8(int rx, int ry, int rw, int rh);
+static Bool HandleHextile16To16(int rx, int ry, int rw, int rh);
+static Bool HandleHextile16To32(int rx, int ry, int rw, int rh);
+static Bool HandleHextile32To8(int rx, int ry, int rw, int rh);
+static Bool HandleHextile32To16(int rx, int ry, int rw, int rh);
+static Bool HandleHextile32To32(int rx, int ry, int rw, int rh);
 static Bool HandleZlib8(int rx, int ry, int rw, int rh);
 static Bool HandleZlib16(int rx, int ry, int rw, int rh);
 static Bool HandleZlib32(int rx, int ry, int rw, int rh);
@@ -222,23 +237,55 @@ JpegSetSrcManager(j_decompress_ptr cinfo, CARD8 *compressedData,
 #define BPP 8
 #include "mrre.c"
 #include "mcorre.c"
-#include "mhextile.c"
 #include "mzlib.c"
 #include "mtight.c"
+#define BPPC 8
+#include "mhextile.c"
+#undef BPPC
+#define BPPC 16
+#include "mhextile.c"
+#include "pixel.c"
+#undef BPPC
+#define BPPC 32
+#include "mhextile.c"
+#include "pixel.c"
+#undef BPPC
 #undef BPP
+
 #define BPP 16
 #include "mrre.c"
 #include "mcorre.c"
-#include "mhextile.c"
 #include "mzlib.c"
 #include "mtight.c"
+#define BPPC 8
+#include "mhextile.c"
+#include "pixel.c"
+#undef BPPC
+#define BPPC 16
+#include "mhextile.c"
+#undef BPPC
+#define BPPC 32
+#include "mhextile.c"
+#include "pixel.c"
+#undef BPPC
 #undef BPP
+
 #define BPP 32
 #include "mrre.c"
 #include "mcorre.c"
-#include "mhextile.c"
 #include "mzlib.c"
 #include "mtight.c"
+#define BPPC 8
+#include "mhextile.c"
+#include "pixel.c"
+#undef BPPC
+#define BPPC 16
+#include "mhextile.c"
+#include "pixel.c"
+#undef BPPC
+#define BPPC 32
+#include "mhextile.c"
+#undef BPPC
 #undef BPP
 
 #define OPTNUM 2
@@ -262,7 +309,7 @@ int client_main(int argc, char **argv)
 
   /* command line check */
   programName = argv[0];
-  while ((c = getopt_long(argc, argv, "d:u:fh", options, &option_index)) != EOF) {
+  while ((c = getopt_long(argc, argv, "d:s:u:fh", options, &option_index)) != EOF) {
 //  while ((c = getopt(argc, argv, "d:u:fnh")) != EOF) {
     switch (c) {
       case 1:
@@ -271,15 +318,23 @@ int client_main(int argc, char **argv)
       case 'd':
 	vncdisplay = optarg;
 	break;
+      case 's':
+	memcpy(connect_server, optarg, IDLENGTH);
+	server_flag = 1;
+        break;
       case 'u':
-	strcpy(client_CB.client_ID, optarg);
+	memcpy((char *)client_CB.client_ID, optarg, IDLENGTH);
 	auto_flag = 1;
 	break;
+      case 'p':
+	passwd_flag = 1;
+//	memcpy((char *)client_CB.passwd, optarg, IDLENGTH);
+	break;
       case 'h':
       case '?':
       default:
 	help(argv[0]);
-	exit(1);
+	exit(EXIT_FAILURE);
 	break;
     }
   }
@@ -319,7 +374,7 @@ ClientInit ()
     dialog_IDinput = (GtkWidget *)create_dialog_IDinput();
     gtk_widget_show(dialog_IDinput);
     gtk_grab_add(dialog_IDinput);
-    draw_string_to_mini_window("Input ID");
+    draw_string_to_mini_window(_("Input ID"));
     gtk_main();
   }
   fprintf(stderr, "vncdisplay=%s\n",vncdisplay);
@@ -363,8 +418,9 @@ JoinCTL ()
   /* Send Client_ID */
   clientadv.type = rfbClientAdv;
   clientadv.length = sizeof(ClientAdv);
-  memcpy(clientadv.client_ID, client_CB.client_ID, 16);
+  memcpy(clientadv.client_ID, client_CB.client_ID, IDLENGTH);
   send (client_CB.ctldsp, &clientadv, sizeof(ClientAdv), 0);
+  printf("clientadv.client_ID: %s\n", client_CB.client_ID);
 
   return True;
 }
@@ -401,9 +457,9 @@ JoinVNC () {
   fprintf (stdout, "%s\n", commandvnc3);
 
   /* execute vncconnect */
-  client_CB.vncdsp = system(commandvnc1);
-  client_CB.vncdsp = system(commandvnc2);
-  client_CB.vncdsp = system(commandvnc3);
+  client_CB.vncdsp = (FILE*)system(commandvnc1);
+  client_CB.vncdsp = (FILE*)system(commandvnc2);
+  client_CB.vncdsp = (FILE*)system(commandvnc3);
 
   client_CB.connectstate = STAT_VNC;
 }
@@ -456,7 +512,7 @@ ClearServerInfo ()
   bzero (&client_CB, sizeof(client_CB));
   client_CB.connectstate = STAT_FIRST;
 
-  draw_string_to_mini_window("ID input ERROR");
+  draw_string_to_mini_window(_("ID input ERROR"));
   dialog_inputmiss = (GtkWidget *)create_dialog_inputmiss();
   gtk_widget_show(dialog_inputmiss);
   gtk_grab_add(dialog_inputmiss);
@@ -477,53 +533,58 @@ MultiRecieve1 ()
   int addr_len = sizeof(recvadd);
   int numrcv;
   ServerAdv serveradv;
-  char recvAdv_msg[256];
 
   bzero(&serveradv, sizeof(ServerAdv));
   numrcv = recvfrom(client_CB.mltdsp, &serveradv, sizeof(ServerAdv), 0, \
-      		    (struct sockaddr *)&recvadd, (int *)&addr_len);
-  memcpy(client_CB.server_ID, serveradv.server_ID, 16);
-  if (auto_flag) {
-    //client_CB.server_ip = inet_addr(SERVER_IP);
-    //client_CB.server_port = htons(SERVER_PORT);
-    client_CB.server_ip = recvadd.sin_addr.s_addr;
-    client_CB.server_port = serveradv.server_port;
+      		    (struct sockaddr *)&recvadd, (socklen_t *)&addr_len);
+  strncpy(client_CB.server_ID, serveradv.server_ID, IDLENGTH);
+
+  if (strcmp((char *)client_CB.server_ID, (char *)client_CB.client_ID) == 0) {
+//  if (memcmp((char *)client_CB.server_ID, (char *)client_CB.client_ID, IDLENGTH) == 0) {
+    client_CB.server_ip = inet_addr(SERVER_IP);
+    client_CB.server_port = htons(SERVER_PORT);
   } else {
     client_CB.server_ip = recvadd.sin_addr.s_addr;
     client_CB.server_port = serveradv.server_port;
   }
   
-  if (dialog_wait != NULL) {
-    gtk_grab_remove(dialog_wait);
-    gtk_widget_destroy(dialog_wait);
-    dialog_wait = NULL;
-  }
-
   fprintf(stderr, "\nrecv-adv %d\n",numrcv);
   fprintf(stderr, "type=%d\n",serveradv.type);
   fprintf(stderr, "length=%d\n",serveradv.length);
   fprintf(stderr, "serverID=%s\n",serveradv.server_ID);
+  fprintf(stderr, "serverID=%x\n",serveradv.server_ID);
   fprintf(stderr, "serverip=%s\n",(char *)inet_ntoa(recvadd.sin_addr));
   fprintf(stderr, "serverport=%d\n\n",ntohs(serveradv.server_port));
 
-  if (auto_flag == 0) {
-    draw_string_to_mini_window("Connect?");
-    dialog_recvAdv = (GtkWidget *)create_dialog_recvAdv();
-    //sprintf(recvAdv_msg, "\343\202\265\343\203\274\343\203\220%s\343\201\213\343\202\211\343\201\256\n\346\216\245\347\266\232\350\246\201\346\261\202\343\202\222\345\217\227\344\277\241\343\201\227\343\201\276\343\201\227\343\201\237\343\200\202\n\n\346\216\245\347\266\232\343\201\227\343\201\276\343\201\231\343\201\213?", serveradv.server_ID);
-    sprintf(recvAdv_msg, "\343\202\265\343\203\274\343\203\220\345\220\215\357\274\232%s\n\n\343\201\223\343\201\256\343\202\265\343\203\274\343\203\220\343\201\253\346\216\245\347\266\232\343\201\227\343\201\276\343\201\231\343\201\213?", serveradv.server_ID);
-    gtk_label_set_text(GTK_LABEL(recvAdv_label), recvAdv_msg);
-    gtk_widget_show(dialog_recvAdv);
-    gtk_grab_add(dialog_recvAdv);
-    gtk_main();
-  } else {
-    draw_string_to_mini_window("Connect");
+  if (!strcmp((char *)connect_server, (char *)serveradv.server_ID)) {
+    server_flag = 2;
   }
 
-  if (((answer == 'y') || (auto_flag == 1)) && JoinCTL ()) {
+  if (server_flag != 1) {
+    if (dialog_wait != NULL) {
+      gtk_grab_remove(dialog_wait);
+      gtk_widget_destroy(dialog_wait);
+      dialog_wait = NULL;
+    }
+  }
+
+
+  /* no option (-u and -s unset) */
+  if ((auto_flag == 0) && (server_flag == 0)) {
+    draw_string_to_mini_window(_("Connect?"));
+    open_dialog_recvAdv((char *)serveradv.server_ID);
+  }
+  /* -u set and -s unset. -s set and match server_ID */
+  else if (((auto_flag == 1) && (server_flag == 0)) || (server_flag == 2)) {
+    draw_string_to_mini_window(_("Connect"));
+  }
+
+  if (((answer == 'y') || ((auto_flag == 1) && (server_flag == 0)) || (server_flag == 2)) && JoinCTL ()) {
     client_CB.connectstate = STAT_ADV;  
     return True;
   } 
   
+  /* -s set and no match server_ID -> infinity loop */
   bzero(client_CB.server_ID, sizeof(client_CB.server_ID));
   client_CB.server_ip = 0;
   client_CB.server_port = 0;
@@ -543,7 +604,7 @@ MultiRecieve2 ()
   existadv.flag = client_CB.state;
 
   numrcv = recvfrom(client_CB.mltdsp, &serveradv, sizeof(ServerAdv), 0, \
-      		    (struct sockaddr *)&recvadd, (int *)&addr_len);
+      		    (struct sockaddr *)&recvadd, (socklen_t *)&addr_len);
   if (memcmp(&client_CB.server_ip, &recvadd.sin_addr, sizeof(CARD32)) != 0)
     return False; 
 
@@ -590,7 +651,7 @@ GetMultiVNCServerMsg (void *g_dsp)
     if (read (client_CB.ctldsp, buf, 2) <= 0) {
       CloseVNCServer();
       fprintf(stderr, "%s : session closed\n", programName);
-      exit (1);
+      exit (EXIT_FAILURE);
     }
     printf("type=%d, flag=%d\n",buf[0],buf[1]);
 
@@ -600,8 +661,14 @@ GetMultiVNCServerMsg (void *g_dsp)
       case rfbAllowAdv:
         printf("switch : rfbAllowAdv\n");
 	if ((client_CB.connectstate == STAT_ADV) || (client_CB.connectstate == STAT_CUT)) {
-	  if (buf[1] == 1) JoinVNC ();
-	  else if (buf[1] == 0) ClearServerInfo (); 
+	  if (buf[1] == 1) {
+	      sleep(rand() %6);
+	      usleep((rand() %2) * 500000);
+              JoinVNC ();
+	  }
+	  else if (buf[1] == 0) {
+              ClearServerInfo (); 
+	  }
 	}
 	break;
 
@@ -613,23 +680,21 @@ GetMultiVNCServerMsg (void *g_dsp)
 	if (read (client_CB.ctldsp, (char *)&castadv + 2, sizeof(CastAdv)-2) <= 0) {
 	  CloseVNCServer();
 	  fprintf(stderr, "%s : session closed\n", programName);
-	  exit (1);
+	  exit (EXIT_FAILURE);
 	}
 
 	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
 	  if ((buf[1] == 1) && (!GETRECV_C)) {
 	    SETRECV_C(1);
-	    draw_string_to_mini_window("Receive Data");
-	    drawing_window = (GtkWidget *)create_drawing_window();
-	    gtk_window_set_default_size(GTK_WINDOW(drawing_window), 600, 400);
 
-	    gtk_label_set_text(GTK_LABEL(screen_label), castadv.src_ID);
-
-	    drawingarea[0][0] = client_drawingarea;
+	    /* Stock data from MultiVNC server */
 	    client_CB.casting_ip = castadv.casting_ip;
 	    client_CB.casting_port = castadv.casting_port;
 	    memcpy (&client_CB.serverInitMsg, &castadv.serverInitMsg, sizeof(rfbServerInitMsg));
 	    memcpy(&si, &client_CB.serverInitMsg, sizeof(rfbServerInitMsg));
+	    draw_string_to_mini_window(_("Receive Data"));
+
+	    /* Create Multicast packet */
 	    printf("ip=%s, port=%d\n",(char *)inet_ntoa(client_CB.casting_ip), \
 							ntohs(client_CB.casting_port));
             client_CB.cstdsp = CreateMultiSockToRecv ((char *)inet_ntoa(client_CB.casting_ip), \
@@ -639,18 +704,34 @@ GetMultiVNCServerMsg (void *g_dsp)
 	    client_CB.g_cstdsp = gdk_input_add (client_CB.cstdsp, GDK_INPUT_READ, \
 		                                (GdkInputFunction)GetMultiVNCServerMsg, \
 						(gpointer)client_CB.cstdsp);
+	    /* Create window for drawing */
+	    drawing_window = (GtkWidget *)create_drawing_window();
+	    gtk_window_set_default_size(GTK_WINDOW(drawing_window), 600, 400);
+
+	    GtkWidget *screen_label = (GtkWidget *)lookup_widget(GTK_WIDGET(drawing_window), "screen_label");
+	    GtkWidget *client_drawingarea = (GtkWidget *)lookup_widget(GTK_WIDGET(drawing_window), "client_drawingarea");
+	    gtk_label_set_text(GTK_LABEL(screen_label), (char *)castadv.src_ID);
+
+	    drawingarea[0][0] = client_drawingarea;
 	    gtk_widget_show(drawing_window);
 	    if (castadv.fullscreen)
 	      gdk_window_fullscreen(gdk_window_get_toplevel(drawing_window->window));
+	    /* Initialize for drawing */
+	    memcpy(&client_CB.serverFormat, &castadv.pixelFormat, sizeof(rfbPixelFormat));
 	    DrawingInit();
+
 	  } else if ((buf[1] == 0) && (GETRECV_C)) {
+            SETRESEND_C(0);
 	    SETRECV_C(0);
 	    gdk_input_remove(client_CB.g_cstdsp);
 	    close(client_CB.cstdsp);
 	    gdk_image_destroy(gdkimage[0]);
 	    gdk_image_destroy(smallimage[0]);
 	    gtk_widget_destroy(drawing_window);
-	    draw_string_to_mini_window("Connect");
+	    gdkimage[0] = NULL;
+	    smallimage[0] = NULL;
+	    drawing_window = NULL;
+	    draw_string_to_mini_window(_("Connect"));
 	  } 
 	}
 	break;
@@ -664,18 +745,18 @@ GetMultiVNCServerMsg (void *g_dsp)
 	if (read (client_CB.ctldsp, (char *)&lockadv + 2, sizeof(LockAdv)-2) <= 0) {
 	  CloseVNCServer();
 	  fprintf(stderr, "%s : session closed\n", programName);
-	  exit (1);
+	  exit (EXIT_FAILURE);
 	}
 
 	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
 	  if (buf[1]) {
 	    if (lock_window == NULL)
 	      create_lock_window();
-	    else { 
+	    else {
 	      start_lock();
 	      gtk_timeout_remove (lock_tag);
 	    }
-	    lock_tag = gtk_timeout_add((lockadv.locktime + 10) * 1000, stop_lock, NULL);
+	    lock_tag = gtk_timeout_add((int)(lockadv.locktime + 10) * 1000, (GtkFunction)stop_lock, NULL);
 	  } else {
 	    gtk_timeout_remove (lock_tag);
 	    stop_lock();
@@ -684,6 +765,37 @@ GetMultiVNCServerMsg (void *g_dsp)
 	break;
       } 
 
+#if 0
+      case rfbRecAdv:
+      {
+	RecAdv recadv;
+
+	printf("switch : rfbRecAdv\n");
+	if (recv (client_CB.ctldsp, (char *)&recadv + 2, sizeof(recadv)-2, 0) <= 0) {
+	  CloseVNCServer();
+	  fprintf(stderr, "%s : session closed\n", programName);
+	  exit (EXIT_FAILURE);
+	}
+
+	if ((client_CB.connectstate == STAT_VNC) || (client_CB.connectstate == STAT_CUT)) {
+	  switch (buf[1]) {
+	    case START:
+	      fprintf(stderr, "recording time:%d fps:%d\n", recadv.rectime, recadv.fps);  
+	      start_record(recadv.fps,recadv.geometry, REC_PATH);
+	      record_tag = gtk_timeout_add(recadv.rectime * 1000, stop_record, NULL);
+	    break;
+
+	    case STOP:
+	      stop_record();
+	    break;
+
+	    default:
+	  }
+	}
+	break;
+      }
+
+#endif
       case rfbVncConnAdv:
         client_CB.connectstate = buf[1];
 	break;
@@ -765,7 +877,7 @@ ReadFromMultiVNCServer(char *out, unsigned int n)
     while (buffered < n) {
 
       int i = recvfrom (rfbsock, buf + buffered, BUF_SIZE - buffered, 0, \
-	  		(struct sockaddr *)&dest, &len);
+	  		(struct sockaddr *)&dest, (socklen_t *)&len);
       if (dest.sin_addr.s_addr != client_CB.server_ip) continue;
 
       if (i <= 0) {
@@ -791,7 +903,7 @@ ReadFromMultiVNCServer(char *out, unsigned int n)
   } else {
     
     while (n > 0) {
-      int i = recvfrom (rfbsock, out, n, 0, (struct sockaddr *)&dest, &len);
+      int i = recvfrom (rfbsock, out, n, 0, (struct sockaddr *)&dest, (socklen_t *)&len);
       if (i <= 0) {
 	if (i < 0) {
 	  if (errno == EWOULDBLOCK || errno == EAGAIN) {
@@ -969,18 +1081,54 @@ HandleMultiVNCServerMessage()
 
       case rfbEncodingHextile:
       {
-	switch (myFormat.bitsPerPixel) {
+	switch (client_CB.serverFormat.bitsPerPixel) {
 	case 8:
-	  if (!HandleHextile8(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
-	    return False;
+	  switch (myFormat.bitsPerPixel) {
+	  case 8:
+	    if (!HandleHextile8To8(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  case 16:
+	    if (!HandleHextile8To16(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  case 32:
+	    if (!HandleHextile8To32(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  }
 	  break;
 	case 16:
-	  if (!HandleHextile16(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
-	    return False;
+	  switch (myFormat.bitsPerPixel) {
+	  case 8:
+	    if (!HandleHextile16To8(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  case 16:
+	    if (!HandleHextile16To16(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  case 32:
+	    if (!HandleHextile16To32(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  }
 	  break;
 	case 32:
-	  if (!HandleHextile32(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
-	    return False;
+	  switch (myFormat.bitsPerPixel) {
+	  case 8:
+	    if (!HandleHextile32To8(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  case 16:
+	    if (!HandleHextile32To16(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  case 32:
+	    if (!HandleHextile32To32(rect.r.x,rect.r.y,rect.r.w,rect.r.h))
+	      return False;
+	    break;
+	  }
 	  break;
 	}
 	break;
@@ -1046,6 +1194,7 @@ help (char *cmd)
 {
   fprintf(stderr, "\nmultivnc_client\n");
   fprintf(stderr, "  -d [num]\t\tDisplay number of vncserver\n\n");
+  fprintf(stderr, "  -s [server_name]\tInput server ID\n\n");
   fprintf(stderr, "  -u [user_name]\tInput client ID and auto connect.\n\n");
   fprintf(stderr, "  --nonotice\t\tState window is not displayed.\n\n");
 }
@@ -1076,3 +1225,18 @@ CloseVNCServer()
   }
 }
 
+int
+adjustColorBitShift(short server_bits, short client_bits)
+{
+  int i, count = 0;
+  short bits;
+
+  bits = server_bits ^ client_bits;
+  for (i = 0; i < 8; i++) {
+    count = count + (bits & 0x01);
+    bits = bits >> 1;
+  }
+
+  return count;
+}
+
