@@ -23,6 +23,8 @@
 
 #include "vncviewer.h"
 
+
+
 char *programName;
 XtAppContext appContext;
 Display* dpy;
@@ -39,13 +41,13 @@ vnc_main(int argc, char **argv)
      command line, getArgsAndResources() will pop up a dialog box and wait
      for one to be entered. */
 
-  GetArgsAndResources(argc, argv);
+//  GetArgsAndResources(argc, argv);
 
-  InitialiseSelection();
+//  InitialiseSelection();
 
   doListen();
   
-  Cleanup();
+//  Cleanup();
 
   return 0;
 }
